@@ -1,6 +1,6 @@
-import sys
 import datetime
 import math
+import sys
 import unittest
 
 from sqlglot import ParseError, alias, exp, parse_one
@@ -277,6 +277,16 @@ class TestExpressions(unittest.TestCase):
             "SELECT * FROM (SELECT 1) AS a /* source: a-b.c */",
         )
 
+    def test_expand_with_lazy_source_provider(self):
+        self.assertEqual(
+            exp.expand(
+                parse_one('select * from "a-b"."C" AS a'),
+                {"`a-b`.c": lambda: parse_one("select 1", dialect="spark")},
+                dialect="spark",
+            ).sql(),
+            "SELECT * FROM (SELECT 1) AS a /* source: a-b.c */",
+        )
+
     def test_replace_placeholders(self):
         self.assertEqual(
             exp.replace_placeholders(
@@ -838,6 +848,7 @@ class TestExpressions(unittest.TestCase):
 
     def test_convert(self):
         from collections import namedtuple
+
         import pytz
 
         PointTuple = namedtuple("Point", ["x", "y"])
